==> xnu-1504.15.3.tar.gz: xnu-xnu-1504.15.3/osfmk/kern/ipc_misc.h <==
/*
 * Copyright (c) 2009 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifdef KERNEL_PRIVATE
#ifndef _KERN_IPC_MISC_H_
#define _KERN_IPC_MISC_H_

struct fileglob;
ipc_port_t fileport_alloc(struct fileglob *);
struct fileglob *fileport_port_to_fileglob(ipc_port_t);
void fileport_notify(mach_msg_header_t *);

#endif /* _KERN_IPC_MISC_H_ */
#endif /* KERNEL_PRIVATE */

==> xnu-10002.1.13.tar.gz: xnu-xnu-10002.1.13/osfmk/kern/ipc_misc.h <==
/*
 * Copyright (c) 2009, 2010 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifdef KERNEL_PRIVATE
#ifndef _KERN_IPC_MISC_H_
#define _KERN_IPC_MISC_H_

struct fileglob;
ipc_port_t fileport_alloc(struct fileglob *);
struct fileglob *fileport_port_to_fileglob(ipc_port_t);
void fileport_notify(mach_msg_header_t *);
kern_return_t fileport_invoke(task_t, mach_port_name_t,
    int (*)(mach_port_name_t, struct fileglob *, void *), void *, int *);
kern_return_t fileport_walk(task_t, size_t *count,
    bool (^cb)(size_t i, mach_port_name_t, struct fileglob *));

#endif /* _KERN_IPC_MISC_H_ */
#endif /* KERNEL_PRIVATE */
